pub struct VoxelPlainIndex(pub usize);Expand description
Identifier for voxels used internally to get rid of user-defined ones.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for VoxelPlainIndex
impl Clone for VoxelPlainIndex
Sourcefn clone(&self) -> VoxelPlainIndex
fn clone(&self) -> VoxelPlainIndex
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoxelPlainIndex
impl Debug for VoxelPlainIndex
Sourceimpl<'de> Deserialize<'de> for VoxelPlainIndex
impl<'de> Deserialize<'de> for VoxelPlainIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for VoxelPlainIndex
impl Hash for VoxelPlainIndex
Sourceimpl<'py> IntoPyObject<'py> for VoxelPlainIndex
impl<'py> IntoPyObject<'py> for VoxelPlainIndex
Sourcetype Target = VoxelPlainIndex
type Target = VoxelPlainIndex
The Python output type
Sourcetype Output = Bound<'py, <VoxelPlainIndex as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <VoxelPlainIndex as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl Ord for VoxelPlainIndex
impl Ord for VoxelPlainIndex
Sourcefn cmp(&self, other: &VoxelPlainIndex) -> Ordering
fn cmp(&self, other: &VoxelPlainIndex) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VoxelPlainIndex
impl PartialEq for VoxelPlainIndex
Sourceimpl PartialOrd for VoxelPlainIndex
impl PartialOrd for VoxelPlainIndex
Sourceimpl PyClass for VoxelPlainIndex
impl PyClass for VoxelPlainIndex
Sourceimpl PyClassImpl for VoxelPlainIndex
impl PyClassImpl for VoxelPlainIndex
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Identifier for voxels used internally to get rid of user-defined ones.
const RAW_DOC: &'static CStr = /// Identifier for voxels used internally to get rid of user-defined ones.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<VoxelPlainIndex>
type ThreadChecker = SendablePyClass<VoxelPlainIndex>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for VoxelPlainIndex
impl PyClassNewTextSignature for VoxelPlainIndex
const TEXT_SIGNATURE: &'static str = "(index)"
Sourceimpl PyMethods<VoxelPlainIndex> for PyClassImplCollector<VoxelPlainIndex>
impl PyMethods<VoxelPlainIndex> for PyClassImplCollector<VoxelPlainIndex>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for VoxelPlainIndex
impl PyTypeInfo for VoxelPlainIndex
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for VoxelPlainIndex
impl Serialize for VoxelPlainIndex
impl Copy for VoxelPlainIndex
impl DerefToPyAny for VoxelPlainIndex
impl Eq for VoxelPlainIndex
impl ExtractPyClassWithClone for VoxelPlainIndex
impl StructuralPartialEq for VoxelPlainIndex