pub enum BoundaryCondition<ConcVecExtracellular> {
Neumann(ConcVecExtracellular),
Dirichlet(ConcVecExtracellular),
Value(ConcVecExtracellular),
}Expand description
The different types of boundary conditions in a PDE system One has to be careful, since the neumann condition is strictly speaking not of the same type since its units are multiplied by 1/time compared to the others. The Value variant is not a boundary condition in the traditional sense but here used as the value which is present in another voxel.
Variants
Neumann(ConcVecExtracellular)
Neumann boundary conditions apply a value to the derivative at the corresponding boundary.
Dirichlet(ConcVecExtracellular)
Dirichlet conditions fix the value of concentration at the boundary.
Value(ConcVecExtracellular)
This boundary condition fixes the value at boundary. Although in principle exactly the same as BoundaryCondition::Dirichlet, this value is not provided by the user but rather the boundary condition of another simulation subdomain.